//go:build go1.18
// +build go1.18

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.
// Code generated by Microsoft (R) AutoRest Code Generator.
// Changes may cause incorrect behavior and will be lost if the code is regenerated.

package armmonitor_test

import (
	"context"
	"log"

	"time"

	"github.com/Azure/azure-sdk-for-go/sdk/azcore/to"
	"github.com/Azure/azure-sdk-for-go/sdk/azidentity"
	"github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/monitor/armmonitor"
)

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/monitor/resource-manager/Microsoft.Insights/stable/2015-04-01/examples/listAutoscaleSetting.json
func ExampleAutoscaleSettingsClient_NewListByResourceGroupPager() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armmonitor.NewAutoscaleSettingsClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	pager := client.NewListByResourceGroupPager("<resource-group-name>",
		nil)
	for pager.More() {
		nextResult, err := pager.NextPage(ctx)
		if err != nil {
			log.Fatalf("failed to advance page: %v", err)
			return
		}
		for _, v := range nextResult.Value {
			// TODO: use page item
			_ = v
		}
	}
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/monitor/resource-manager/Microsoft.Insights/stable/2015-04-01/examples/createOrUpdateAutoscaleSetting.json
func ExampleAutoscaleSettingsClient_CreateOrUpdate() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armmonitor.NewAutoscaleSettingsClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	res, err := client.CreateOrUpdate(ctx,
		"<resource-group-name>",
		"<autoscale-setting-name>",
		armmonitor.AutoscaleSettingResource{
			Location: to.Ptr("<location>"),
			Tags:     map[string]*string{},
			Properties: &armmonitor.AutoscaleSetting{
				Enabled: to.Ptr(true),
				Notifications: []*armmonitor.AutoscaleNotification{
					{
						Email: &armmonitor.EmailNotification{
							CustomEmails: []*string{
								to.Ptr("gu@ms.com"),
								to.Ptr("ge@ns.net")},
							SendToSubscriptionAdministrator:    to.Ptr(true),
							SendToSubscriptionCoAdministrators: to.Ptr(true),
						},
						Operation: to.Ptr("<operation>"),
						Webhooks: []*armmonitor.WebhookNotification{
							{
								Properties: map[string]*string{},
								ServiceURI: to.Ptr("<service-uri>"),
							}},
					}},
				Profiles: []*armmonitor.AutoscaleProfile{
					{
						Name: to.Ptr("<name>"),
						Capacity: &armmonitor.ScaleCapacity{
							Default: to.Ptr("<default>"),
							Maximum: to.Ptr("<maximum>"),
							Minimum: to.Ptr("<minimum>"),
						},
						FixedDate: &armmonitor.TimeWindow{
							End:      to.Ptr(func() time.Time { t, _ := time.Parse(time.RFC3339Nano, "2015-03-05T14:30:00Z"); return t }()),
							Start:    to.Ptr(func() time.Time { t, _ := time.Parse(time.RFC3339Nano, "2015-03-05T14:00:00Z"); return t }()),
							TimeZone: to.Ptr("<time-zone>"),
						},
						Rules: []*armmonitor.ScaleRule{
							{
								MetricTrigger: &armmonitor.MetricTrigger{
									DividePerInstance: to.Ptr(false),
									MetricName:        to.Ptr("<metric-name>"),
									MetricResourceURI: to.Ptr("<metric-resource-uri>"),
									Operator:          to.Ptr(armmonitor.ComparisonOperationTypeGreaterThan),
									Statistic:         to.Ptr(armmonitor.MetricStatisticTypeAverage),
									Threshold:         to.Ptr[float64](10),
									TimeAggregation:   to.Ptr(armmonitor.TimeAggregationTypeAverage),
									TimeGrain:         to.Ptr("<time-grain>"),
									TimeWindow:        to.Ptr("<time-window>"),
								},
								ScaleAction: &armmonitor.ScaleAction{
									Type:      to.Ptr(armmonitor.ScaleTypeChangeCount),
									Cooldown:  to.Ptr("<cooldown>"),
									Direction: to.Ptr(armmonitor.ScaleDirectionIncrease),
									Value:     to.Ptr("<value>"),
								},
							},
							{
								MetricTrigger: &armmonitor.MetricTrigger{
									DividePerInstance: to.Ptr(false),
									MetricName:        to.Ptr("<metric-name>"),
									MetricResourceURI: to.Ptr("<metric-resource-uri>"),
									Operator:          to.Ptr(armmonitor.ComparisonOperationTypeGreaterThan),
									Statistic:         to.Ptr(armmonitor.MetricStatisticTypeAverage),
									Threshold:         to.Ptr[float64](15),
									TimeAggregation:   to.Ptr(armmonitor.TimeAggregationTypeAverage),
									TimeGrain:         to.Ptr("<time-grain>"),
									TimeWindow:        to.Ptr("<time-window>"),
								},
								ScaleAction: &armmonitor.ScaleAction{
									Type:      to.Ptr(armmonitor.ScaleTypeChangeCount),
									Cooldown:  to.Ptr("<cooldown>"),
									Direction: to.Ptr(armmonitor.ScaleDirectionDecrease),
									Value:     to.Ptr("<value>"),
								},
							}},
					},
					{
						Name: to.Ptr("<name>"),
						Capacity: &armmonitor.ScaleCapacity{
							Default: to.Ptr("<default>"),
							Maximum: to.Ptr("<maximum>"),
							Minimum: to.Ptr("<minimum>"),
						},
						Recurrence: &armmonitor.Recurrence{
							Frequency: to.Ptr(armmonitor.RecurrenceFrequencyWeek),
							Schedule: &armmonitor.RecurrentSchedule{
								Days: []*string{
									to.Ptr("1")},
								Hours: []*int32{
									to.Ptr[int32](5)},
								Minutes: []*int32{
									to.Ptr[int32](15)},
								TimeZone: to.Ptr("<time-zone>"),
							},
						},
						Rules: []*armmonitor.ScaleRule{
							{
								MetricTrigger: &armmonitor.MetricTrigger{
									DividePerInstance: to.Ptr(false),
									MetricName:        to.Ptr("<metric-name>"),
									MetricResourceURI: to.Ptr("<metric-resource-uri>"),
									Operator:          to.Ptr(armmonitor.ComparisonOperationTypeGreaterThan),
									Statistic:         to.Ptr(armmonitor.MetricStatisticTypeAverage),
									Threshold:         to.Ptr[float64](10),
									TimeAggregation:   to.Ptr(armmonitor.TimeAggregationTypeAverage),
									TimeGrain:         to.Ptr("<time-grain>"),
									TimeWindow:        to.Ptr("<time-window>"),
								},
								ScaleAction: &armmonitor.ScaleAction{
									Type:      to.Ptr(armmonitor.ScaleTypeChangeCount),
									Cooldown:  to.Ptr("<cooldown>"),
									Direction: to.Ptr(armmonitor.ScaleDirectionIncrease),
									Value:     to.Ptr("<value>"),
								},
							},
							{
								MetricTrigger: &armmonitor.MetricTrigger{
									DividePerInstance: to.Ptr(false),
									MetricName:        to.Ptr("<metric-name>"),
									MetricResourceURI: to.Ptr("<metric-resource-uri>"),
									Operator:          to.Ptr(armmonitor.ComparisonOperationTypeGreaterThan),
									Statistic:         to.Ptr(armmonitor.MetricStatisticTypeAverage),
									Threshold:         to.Ptr[float64](15),
									TimeAggregation:   to.Ptr(armmonitor.TimeAggregationTypeAverage),
									TimeGrain:         to.Ptr("<time-grain>"),
									TimeWindow:        to.Ptr("<time-window>"),
								},
								ScaleAction: &armmonitor.ScaleAction{
									Type:      to.Ptr(armmonitor.ScaleTypeChangeCount),
									Cooldown:  to.Ptr("<cooldown>"),
									Direction: to.Ptr(armmonitor.ScaleDirectionDecrease),
									Value:     to.Ptr("<value>"),
								},
							}},
					}},
				TargetResourceURI: to.Ptr("<target-resource-uri>"),
			},
		},
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	// TODO: use response item
	_ = res
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/monitor/resource-manager/Microsoft.Insights/stable/2015-04-01/examples/deleteAutoscaleSetting.json
func ExampleAutoscaleSettingsClient_Delete() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armmonitor.NewAutoscaleSettingsClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	_, err = client.Delete(ctx,
		"<resource-group-name>",
		"<autoscale-setting-name>",
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/monitor/resource-manager/Microsoft.Insights/stable/2015-04-01/examples/getAutoscaleSetting.json
func ExampleAutoscaleSettingsClient_Get() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armmonitor.NewAutoscaleSettingsClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	res, err := client.Get(ctx,
		"<resource-group-name>",
		"<autoscale-setting-name>",
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	// TODO: use response item
	_ = res
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/monitor/resource-manager/Microsoft.Insights/stable/2015-04-01/examples/patchAutoscaleSetting.json
func ExampleAutoscaleSettingsClient_Update() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armmonitor.NewAutoscaleSettingsClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	res, err := client.Update(ctx,
		"<resource-group-name>",
		"<autoscale-setting-name>",
		armmonitor.AutoscaleSettingResourcePatch{
			Properties: &armmonitor.AutoscaleSetting{
				Enabled: to.Ptr(true),
				Notifications: []*armmonitor.AutoscaleNotification{
					{
						Email: &armmonitor.EmailNotification{
							CustomEmails: []*string{
								to.Ptr("gu@ms.com"),
								to.Ptr("ge@ns.net")},
							SendToSubscriptionAdministrator:    to.Ptr(true),
							SendToSubscriptionCoAdministrators: to.Ptr(true),
						},
						Operation: to.Ptr("<operation>"),
						Webhooks: []*armmonitor.WebhookNotification{
							{
								Properties: map[string]*string{},
								ServiceURI: to.Ptr("<service-uri>"),
							}},
					}},
				Profiles: []*armmonitor.AutoscaleProfile{
					{
						Name: to.Ptr("<name>"),
						Capacity: &armmonitor.ScaleCapacity{
							Default: to.Ptr("<default>"),
							Maximum: to.Ptr("<maximum>"),
							Minimum: to.Ptr("<minimum>"),
						},
						FixedDate: &armmonitor.TimeWindow{
							End:      to.Ptr(func() time.Time { t, _ := time.Parse(time.RFC3339Nano, "2015-03-05T14:30:00Z"); return t }()),
							Start:    to.Ptr(func() time.Time { t, _ := time.Parse(time.RFC3339Nano, "2015-03-05T14:00:00Z"); return t }()),
							TimeZone: to.Ptr("<time-zone>"),
						},
						Rules: []*armmonitor.ScaleRule{
							{
								MetricTrigger: &armmonitor.MetricTrigger{
									DividePerInstance: to.Ptr(false),
									MetricName:        to.Ptr("<metric-name>"),
									MetricResourceURI: to.Ptr("<metric-resource-uri>"),
									Operator:          to.Ptr(armmonitor.ComparisonOperationTypeGreaterThan),
									Statistic:         to.Ptr(armmonitor.MetricStatisticTypeAverage),
									Threshold:         to.Ptr[float64](10),
									TimeAggregation:   to.Ptr(armmonitor.TimeAggregationTypeAverage),
									TimeGrain:         to.Ptr("<time-grain>"),
									TimeWindow:        to.Ptr("<time-window>"),
								},
								ScaleAction: &armmonitor.ScaleAction{
									Type:      to.Ptr(armmonitor.ScaleTypeChangeCount),
									Cooldown:  to.Ptr("<cooldown>"),
									Direction: to.Ptr(armmonitor.ScaleDirectionIncrease),
									Value:     to.Ptr("<value>"),
								},
							},
							{
								MetricTrigger: &armmonitor.MetricTrigger{
									DividePerInstance: to.Ptr(false),
									MetricName:        to.Ptr("<metric-name>"),
									MetricResourceURI: to.Ptr("<metric-resource-uri>"),
									Operator:          to.Ptr(armmonitor.ComparisonOperationTypeGreaterThan),
									Statistic:         to.Ptr(armmonitor.MetricStatisticTypeAverage),
									Threshold:         to.Ptr[float64](15),
									TimeAggregation:   to.Ptr(armmonitor.TimeAggregationTypeAverage),
									TimeGrain:         to.Ptr("<time-grain>"),
									TimeWindow:        to.Ptr("<time-window>"),
								},
								ScaleAction: &armmonitor.ScaleAction{
									Type:      to.Ptr(armmonitor.ScaleTypeChangeCount),
									Cooldown:  to.Ptr("<cooldown>"),
									Direction: to.Ptr(armmonitor.ScaleDirectionDecrease),
									Value:     to.Ptr("<value>"),
								},
							}},
					},
					{
						Name: to.Ptr("<name>"),
						Capacity: &armmonitor.ScaleCapacity{
							Default: to.Ptr("<default>"),
							Maximum: to.Ptr("<maximum>"),
							Minimum: to.Ptr("<minimum>"),
						},
						Recurrence: &armmonitor.Recurrence{
							Frequency: to.Ptr(armmonitor.RecurrenceFrequencyWeek),
							Schedule: &armmonitor.RecurrentSchedule{
								Days: []*string{
									to.Ptr("1")},
								Hours: []*int32{
									to.Ptr[int32](5)},
								Minutes: []*int32{
									to.Ptr[int32](15)},
								TimeZone: to.Ptr("<time-zone>"),
							},
						},
						Rules: []*armmonitor.ScaleRule{
							{
								MetricTrigger: &armmonitor.MetricTrigger{
									DividePerInstance: to.Ptr(false),
									MetricName:        to.Ptr("<metric-name>"),
									MetricResourceURI: to.Ptr("<metric-resource-uri>"),
									Operator:          to.Ptr(armmonitor.ComparisonOperationTypeGreaterThan),
									Statistic:         to.Ptr(armmonitor.MetricStatisticTypeAverage),
									Threshold:         to.Ptr[float64](10),
									TimeAggregation:   to.Ptr(armmonitor.TimeAggregationTypeAverage),
									TimeGrain:         to.Ptr("<time-grain>"),
									TimeWindow:        to.Ptr("<time-window>"),
								},
								ScaleAction: &armmonitor.ScaleAction{
									Type:      to.Ptr(armmonitor.ScaleTypeChangeCount),
									Cooldown:  to.Ptr("<cooldown>"),
									Direction: to.Ptr(armmonitor.ScaleDirectionIncrease),
									Value:     to.Ptr("<value>"),
								},
							},
							{
								MetricTrigger: &armmonitor.MetricTrigger{
									DividePerInstance: to.Ptr(false),
									MetricName:        to.Ptr("<metric-name>"),
									MetricResourceURI: to.Ptr("<metric-resource-uri>"),
									Operator:          to.Ptr(armmonitor.ComparisonOperationTypeGreaterThan),
									Statistic:         to.Ptr(armmonitor.MetricStatisticTypeAverage),
									Threshold:         to.Ptr[float64](15),
									TimeAggregation:   to.Ptr(armmonitor.TimeAggregationTypeAverage),
									TimeGrain:         to.Ptr("<time-grain>"),
									TimeWindow:        to.Ptr("<time-window>"),
								},
								ScaleAction: &armmonitor.ScaleAction{
									Type:      to.Ptr(armmonitor.ScaleTypeChangeCount),
									Cooldown:  to.Ptr("<cooldown>"),
									Direction: to.Ptr(armmonitor.ScaleDirectionDecrease),
									Value:     to.Ptr("<value>"),
								},
							}},
					}},
				TargetResourceURI: to.Ptr("<target-resource-uri>"),
			},
			Tags: map[string]*string{
				"$type": to.Ptr("Microsoft.WindowsAzure.Management.Common.Storage.CasePreservedDictionary"),
			},
		},
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	// TODO: use response item
	_ = res
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/monitor/resource-manager/Microsoft.Insights/stable/2015-04-01/examples/listAutoscaleSettingBySubscription.json
func ExampleAutoscaleSettingsClient_NewListBySubscriptionPager() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armmonitor.NewAutoscaleSettingsClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	pager := client.NewListBySubscriptionPager(nil)
	for pager.More() {
		nextResult, err := pager.NextPage(ctx)
		if err != nil {
			log.Fatalf("failed to advance page: %v", err)
			return
		}
		for _, v := range nextResult.Value {
			// TODO: use page item
			_ = v
		}
	}
}
